@@ -23,7 +23,8 @@ class Actions:
         alert = deepcopy(alert)
         # From this: {"displayName": "batch_start_millis", "value": "1632146400000"}
         # To this: {"batch_start_millis": "1632146400000"}
-        alert['additionalFields'] = {x['displayName']: x['value'] for x in alert.get('additionalFields', {}) if x.get('displayName')}
+        # ToDo 2022-03-09, research further and verify since m92: the step below causes a failure now, and it looks like it's because the alert API is returning cleaner results now
+        # alert['additionalFields'] = {x['displayName']: x['value'] for x in alert.get('additionalFields', {}) if x.get('displayName')}
 
         # From this: {"caseFieldId": "field-17", "displayName": "Alert Context", "fieldType": "Text", "value": "mdr_test"}
         # To this: {"Alert Context": "mdr_test"}
@@ -71,11 +72,17 @@ class Actions:
         if not included_standard_fields and not included_additional_fields:
             return alert
 
-        additional_fields = alert.pop('additionalFields', [])
-        additional_fields = [f for f in additional_fields if not included_additional_fields or f.get('displayName') in included_additional_fields]
+        additional_fields = alert.pop('additionalFields', {})
+        if isinstance(additional_fields, list):
+            additional_fields = [f for f in additional_fields if not included_additional_fields or f.get('displayName') in included_additional_fields]
+        else:
+            additional_fields = {k: v for k, v in additional_fields.items() if not included_additional_fields or k in included_additional_fields}
 
         mapped_fields = alert.pop('mappedAlertFieldValues', [])
-        mapped_fields = [f for f in mapped_fields if not included_standard_fields or f.get('displayName') in included_standard_fields]
+        if isinstance(mapped_fields, list):
+            mapped_fields = [f for f in mapped_fields if not included_standard_fields or f.get('displayName') in included_standard_fields]
+        else:
+            mapped_fields = {k: v for k, v in mapped_fields.items() if not included_standard_fields or k in included_standard_fields}
 
         new_alert = {'id': alert.pop('id')}
         new_alert.update({k: v for k, v in alert.items() if not included_standard_fields or k in included_standard_fields})
@@ -276,6 +283,16 @@ class Actions:
         _ = self._result_dict_has_schema(result, "result", "data", "data", action_description="list notebooks", raise_errors=True)
         return result["result"]["data"]
 
+    @property
+    def playbook_ids(self):
+        response = self.list_playbooks()
+        return {p["id"]["id"]: p["name"] for p in response}
+
+    def list_playbooks(self, limit=None):
+        response = self.__api.list_playbooks(limit=limit)
+        _ = self._result_dict_has_schema(response, "result", "data", "data")
+        return response["result"]["data"]["data"]
+
     def list_streams(self, search_text: str = None, filters: list = None, limit: int = 25, offset: int = 0):
         result = self.__api.list_streams(search_text=search_text, filters=filters, limit=limit, offset=offset)
         _ = self._result_dict_has_schema(result, "result", "data", "data", raise_errors=True, action_description="list streams")
@@ -330,10 +347,10 @@ class Actions:
     def search_alerts_advanced(self, query: str = None, limit: int = None, fetch_details=None, included_standard_fields=None, included_additional_fields=None):
         simple_format = False
         if fetch_details:
-            if fetch_details not in ['standard', 'simple']:
-                raise ValueError(f'Invalid input for fetch_details: {fetch_details}')
-            elif fetch_details == 'simple':
+            if fetch_details == 'simple':
                 simple_format = True
+            elif fetch_details != 'standard':
+                raise ValueError(f'Invalid input for fetch_details: {fetch_details}')
         query = query.strip() if query and query.strip() else ""
         result = self.__api.alerts_search_advanced(query=query, limit=limit)
         _ = self._result_dict_has_schema(result, "result", action_description="search alerts", raise_errors=True)
@@ -360,9 +377,11 @@ class Actions:
 class LogicHub:
     verify_ssl = True
 
-    def __init__(self, hostname, api_key=None, username=None, password=None, verify_ssl=True, cache_seconds=None, verify_api_auth=True, logger: Logger=None, **kwargs):
+    def __init__(self, hostname, api_key=None, username=None, password=None, verify_ssl=True, cache_seconds=None, verify_api_auth=True, logger: Logger = None, log_level=None, **kwargs):
         # If the LogicHubAPI class object has not been given a logger by the time this class is instantiated, set one for it
         LogicHubAPI.log = LogicHubAPI.log or logger or Logger()
+        if log_level:
+            LogicHubAPI.log.log_level = log_level
 
         LogicHubAPI.verify_ssl = self.verify_ssl
 
