@@ -1,3 +1,4 @@
+# ToDo Revisit: /api/ by itself returns a health status but does not support token auth
 class URLs:
     _version = 0
 
@@ -155,6 +156,10 @@ class URLs:
     def modules(self):
         return f"{self.base}/api/content-exchange/browse/Module"
 
+    @property
+    def ml_models(self):
+        return f"{self.base}/api/listMLModels"
+
     @property
     def notebooks_attach(self):
         return f"{self.base}/api/notebook/attachNotebooksToEntity"
